==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgshortcuts.cpp <==
/***************************************************************************
                          dlgshortcuts.cpp  -  Macro keys dialog box
                             -------------------
    begin                : Pi mj 30 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "../dialogs/dlgshortcuts.h"
#include "../dialogs/dlgeditshortcut.h"

#include "../cshortcutlist.h"
#include "../cshortcut.h"

#include <qlabel.h>
#include <qlayout.h>
#include <klocale.h>
#include <kpushbutton.h>
#include <kapp.h>
#include <kmessagebox.h>

//cShortcut-based stuff is called macro keys in the program...
//I just don't want to rename all those classes...

dlgShortcuts::dlgShortcuts (cShortcutList *slist, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Macro keys"), Ok, Ok, true)
{
  sl = slist;

  createDialog ();
}

dlgShortcuts::~dlgShortcuts ()
{

}

void dlgShortcuts::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (500, 400));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 2, 2);

  setMainWidget (page);

  //change button text
  setButtonOKText (i18n ("Done"));

  //create widgets
  QLabel *label = new QLabel (i18n ("&List of macro keys"), page);
  box = new KListBox (page);
  label->setBuddy (box);
  QFrame *buttons = new QFrame (page);
  QVBoxLayout *buttonslayout = new QVBoxLayout (buttons);

  btadd = new KPushButton (i18n ("&Add..."), buttons);
  btmodify = new KPushButton (i18n ("&Modify..."), buttons);
  btdelete = new KPushButton (i18n ("&Delete"), buttons);

  buttonslayout->setSpacing (5);
  buttonslayout->addWidget (btadd);
  buttonslayout->addWidget (btmodify);
  buttonslayout->addWidget (btdelete);
  buttonslayout->addStretch (10);

  layout->setColStretch (0, 10);
  layout->setRowStretch (1, 10);
  layout->setSpacing (5);

  //place out widgets
  layout->addWidget (label, 0, 0);
  layout->addWidget (box, 1, 0);
  layout->addWidget (buttons, 1, 1);

  //update the listbox
  updateMe ();

  //connect() the whole stuff!
  connect (btadd, SIGNAL (clicked ()), this, SLOT (add ()));
  connect (btmodify, SIGNAL (clicked ()), this, SLOT (modify ()));
  connect (btdelete, SIGNAL (clicked ()), this, SLOT (remove ()));
  connect (box, SIGNAL (doubleClicked (QListBoxItem *)), this, SLOT (modify ()));
}

void dlgShortcuts::add ()
{
  //we show Edit timer dialog
  cShortcut *shortcut = new cShortcut (sl->session());
  dlgEditShortcut *edit = new dlgEditShortcut (shortcut, this);

  //determine position for the new object
  int it = box->currentItem ();
  
  if (edit->showMe ())
  {
    if (it >= 0)
    {
      sl->reset ();
      for (int i = 0; i < it; i++)
        (*sl)++;
    }
    //item now contains new data, so just add it to the list!
    if (it >= 0)
      sl->addAfterCurrent (shortcut);
    else
      sl->addToEnd (shortcut);
    updateMe ();
  }
  else
    delete shortcut;
  delete edit;

  if (it >= 0)
    it++;
  else
    it = sl->count () - 1;
  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgShortcuts::modify ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  sl->reset ();
  for (int i = 0; i < it; i++)
    (*sl)++;
  cShortcut *shortcut = (cShortcut *) **sl;
  dlgEditShortcut *edit = new dlgEditShortcut (shortcut, this);
  if (edit->showMe ())
    //if he pressed OK, field already contains new data -> we only have to
    //update the listbox...
    updateMe ();
  delete edit;

  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgShortcuts::remove ()
{
  //get that item
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough

  //ask: really?
  int n = KMessageBox::questionYesNoCancel (this,
        i18n ("Do you really want to delete this macro key?"),
        i18n ("Delete macro key"));
  if (n == KMessageBox::Yes)
  {
    //really!
    //current item MUST be found AFTER the message box invocation; otherwise
    //some keypress would modify that
    sl->reset ();
    for (int i = 0; i < it; i++)
      (*sl)++;
    sl->removeCurrent ();
    updateMe ();
  }
}

void dlgShortcuts::updateMe ()
{
  //remember old index
  int idx = box->currentItem ();

  box->clear ();
  for (sl->reset(); (*sl); (*sl)++)
  {
    cShortcut *s = (cShortcut *) **sl;
    QString name = cShortcut::keyToString (s->key(), s->state());
    name += " -> " + s->getText ();
    box->insertItem (name);
  }

  //make one item active, trying to be intelligent...
  box->setCurrentItem ((idx == -1) ? 0 : idx);
  if ((box->currentItem () == -1) && (idx != -1))
    box->setCurrentItem (idx - 1);
  if (box->currentItem () == -1)
    box->setCurrentItem (0);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgshortcuts.cpp <==
/***************************************************************************
                          dlgshortcuts.cpp  -  Macro keys dialog box
                             -------------------
    begin                : Pi mj 30 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlgshortcuts.h"
#include "dlgeditshortcut.h"

#include "cshortcutlist.h"
#include "cshortcut.h"

#include <qlabel.h>
#include <qlayout.h>
#include <klocale.h>
#include <kpushbutton.h>
#include <kapp.h>
#include <kmessagebox.h>

//cShortcut-based stuff is called macro keys in the program...
//I just don't want to rename all those classes...

dlgShortcuts::dlgShortcuts (cShortcutList *slist, QWidget *parent, const char *name) :
    KDialogBase (parent, name, true, i18n ("Macro keys"), Ok, Ok, true)
{
  sl = slist;

  createDialog ();
}

dlgShortcuts::~dlgShortcuts ()
{

}

void dlgShortcuts::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (500, 400));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 2, 2);

  setMainWidget (page);

  //change button text
  setButtonOKText (i18n ("Done"));

  //create widgets
  QLabel *label = new QLabel (i18n ("&List of macro keys"), page);
  box = new KListBox (page);
  label->setBuddy (box);
  QFrame *buttons = new QFrame (page);
  QVBoxLayout *buttonslayout = new QVBoxLayout (buttons);

  btadd = new KPushButton (i18n ("&Add..."), buttons);
  btmodify = new KPushButton (i18n ("&Modify..."), buttons);
  btdelete = new KPushButton (i18n ("&Delete"), buttons);

  buttonslayout->setSpacing (5);
  buttonslayout->addWidget (btadd);
  buttonslayout->addWidget (btmodify);
  buttonslayout->addWidget (btdelete);
  buttonslayout->addStretch (10);

  layout->setColStretch (0, 10);
  layout->setRowStretch (1, 10);
  layout->setSpacing (5);

  //place out widgets
  layout->addWidget (label, 0, 0);
  layout->addWidget (box, 1, 0);
  layout->addWidget (buttons, 1, 1);

  //update the listbox
  updateMe ();

  //connect() the whole stuff!
  connect (btadd, SIGNAL (clicked ()), this, SLOT (add ()));
  connect (btmodify, SIGNAL (clicked ()), this, SLOT (modify ()));
  connect (btdelete, SIGNAL (clicked ()), this, SLOT (remove ()));
  connect (box, SIGNAL (doubleClicked (QListBoxItem *)), this, SLOT (modify ()));
}

void dlgShortcuts::add ()
{
  //we show Edit timer dialog
  cShortcut *shortcut = new cShortcut (sl->sess());
  dlgEditShortcut *edit = new dlgEditShortcut (shortcut, this);

  //determine position for the new object
  int it = box->currentItem ();
  
  if (edit->showMe ())
  {
    if (it >= 0)
    {
      sl->reset ();
      for (int i = 0; i < it; i++)
        (*sl)++;
    }
    //item now contains new data, so just add it to the list!
    if (it >= 0)
      sl->addAfterCurrent (shortcut);
    else
      sl->addToEnd (shortcut);
    updateMe ();
  }
  else
    delete shortcut;
  delete edit;

  if (it >= 0)
    it++;
  else
    it = sl->count () - 1;
  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgShortcuts::modify ()
{
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough
  sl->reset ();
  for (int i = 0; i < it; i++)
    (*sl)++;
  cShortcut *shortcut = (cShortcut *) **sl;
  dlgEditShortcut *edit = new dlgEditShortcut (shortcut, this);
  if (edit->showMe ())
    //if he pressed OK, field already contains new data -> we only have to
    //update the listbox...
    updateMe ();
  delete edit;

  box->setSelected (it, true);
  box->setCurrentItem (it);
}

void dlgShortcuts::remove ()
{
  //get that item
  int it = box->currentItem ();
  if (it < 0) return;
  if (!box->isSelected (it)) return;  //item must be also selected, focus is NOT enough

  //ask: really?
  int n = KMessageBox::questionYesNoCancel (this,
        i18n ("Do you really want to delete this macro key?"),
        i18n ("Delete macro key"));
  if (n == KMessageBox::Yes)
  {
    //really!
    //current item MUST be found AFTER the message box invocation; otherwise
    //some keypress would modify that
    sl->reset ();
    for (int i = 0; i < it; i++)
      (*sl)++;
    sl->removeCurrent ();
    updateMe ();
  }
}

void dlgShortcuts::updateMe ()
{
  //remember old index
  int idx = box->currentItem ();

  box->clear ();
  for (sl->reset(); (*sl); (*sl)++)
  {
    cShortcut *s = (cShortcut *) **sl;
    QString name = cShortcut::keyToString (s->key(), s->state());
    name += " -> " + s->getText ();
    box->insertItem (name);
  }

  //make one item active, trying to be intelligent...
  box->setCurrentItem ((idx == -1) ? 0 : idx);
  if ((box->currentItem () == -1) && (idx != -1))
    box->setCurrentItem (idx - 1);
  if (box->currentItem () == -1)
    box->setCurrentItem (0);
}
